# servicex_clients
 An umbrella package that will include servicex client packages

## Packages

The following ServiceX frontend clients are installed when you install this library.

- [tcut-to-castle](https://pypi.org/project/tcut-to-qastle/) - The TCut library that uses TCut like syntax to drive ServiceX selections.
- [func_adl_servicex](https://pypi.org/project/func-adl-servicex/) - The func_adl front-end for using servicex.
